<a href="https://github.com/AidenEllis/Cligo"><p align="center"></a>
<img height=100 src="https://44.media.tumblr.com/777597e4c5463d8631cb86c2a9fd583a/tumblr_muttcwX7Tc1sjre2oo1_400.gif"/>


<p align="center">
  <strong>This Project is in developement (Reserved) 🥞</strong>
</p>

<h3 align="center">
  <a href="https://www.youtube.com/watch?v=dQw4w9WgXcQ">Surprise</a>
  <span> · </span>
  <a href="https://www.youtube.com/watch?v=p6wtyU7HqpI">free tiddies</a>
  <span> · </span>
  <a href="https://www.youtube.com/watch?v=PV3_UHG73oQ">Sandwich</a>
</h3>

##

<p>Wanna Reserve Your Pypi project? Check out <a href="https://github.com/AidenEllis/PypiNameReserver">PypiNameReserver</a>.</p>
